@@ -64,16 +64,21 @@ def main():
 
     params1 = ulog1.initial_parameters
     params2 = ulog2.initial_parameters
+    changed_params1 = ulog1.changed_parameters
+    changed_params2 = ulog2.changed_parameters
     if args.default is not None:
         params1 = get_defaults(ulog1, args.default)
         args.initial = True
 
+    changed_param1_list = dict([(i[1],i[2]) for i in changed_params1])
     param_keys1 = sorted(params1.keys())
+    param_keys1_minusinflight = sorted(params1.keys()) - changed_param1_list.keys()
     param_keys2 = sorted(params2.keys())
     delimiter = args.delimiter
     output_file = args.output_filename
     version1 = ''
     version2 = ''
+    output_file.write('\n')
 
     if 'boot_console_output' in ulog1.msg_info_multiple_dict:
         console_output = ulog1.msg_info_multiple_dict['boot_console_output'][0]
@@ -111,24 +116,64 @@ def main():
                 output_file.write('Deleted: ')
                 output_file.write(param_key1)
                 output_file.write('\n')
-
-        for param_key1 in param_keys1:
+                output_file.write('\n')
+        output_file.write('\nChanged pre-flight:\n')
+        for param_key1 in param_keys1_minusinflight:
             for param_key2 in param_keys2:
-                if (param_key1 == param_key2) and (param_key1 != 'LND_FLIGHT_T_LO') and (param_key1 != 'COM_FLIGHT_UUID'):
+                if (param_key1 == param_key2) and (param_key1 != 'LND_FLIGHT_T_LO') and (param_key1 != 'LND_FLIGHT_T_HI') and (param_key1 != 'COM_FLIGHT_UUID'):
                     if isinstance(params1[param_key1],float):
                         if (abs(params1[param_key1] - params2[param_key2]) > 0.001):
-                            output_file.write(param_key1)
-                            output_file.write(': ')
-                            output_file.write(str(round(params1[param_key1],5)))
-                            output_file.write(' -> ')
-                            output_file.write(str(round(params2[param_key2],5)))
-                            output_file.write('\n')
+                                output_file.write(param_key1)
+                                output_file.write(': ')
+                                output_file.write(str(round(params1[param_key1],5)))
+                                output_file.write(' -> ')
+                                output_file.write(str(round(params2[param_key2],5)))
+                                output_file.write('\n')
                     else:
                         if (params1[param_key1] != params2[param_key2]):
-                            output_file.write(param_key1)
-                            output_file.write(': ')
-                            output_file.write(str(params1[param_key1]))
-                            output_file.write(' -> ')
-                            output_file.write(str(params2[param_key2]))
-                            output_file.write('\n')
-
+                                output_file.write(param_key1)
+                                output_file.write(': ')
+                                output_file.write(str(params1[param_key1]))
+                                output_file.write(' -> ')
+                                output_file.write(str(params2[param_key2]))
+                                output_file.write('\n')
+        last_matched = ''
+        last_matched_val = 0.0
+        output_file.write('\nChanged in-flight:\n')
+        for param_key2 in param_keys2:
+            for i in changed_params2:
+                if (param_key2 == i[1]) and (param_key2 != 'LND_FLIGHT_T_LO') and (param_key1 != 'LND_FLIGHT_T_HI') and (param_key2 != 'COM_FLIGHT_UUID'):
+                    if isinstance(params2[param_key2],float):
+                        if (abs(params2[param_key2] - i[2]) > 0.001):
+                            if (last_matched != i[1]):
+                                output_file.write(param_key2)
+                                output_file.write(': ')
+                                output_file.write(str(round(params2[param_key2],5)))
+                                output_file.write(' -> ')
+                                output_file.write(str(round(i[2],5)))
+                                output_file.write('\n')
+                                last_matched = i[1]
+                                last_matched_val = i[2]
+                            else:
+                                output_file.write(last_matched)
+                                output_file.write(': ')
+                                output_file.write(str(round(last_matched_val,5)))
+                                output_file.write(' -> ')
+                                output_file.write(str(round(i[2],5)))
+                                output_file.write('\n')
+                    else:
+                        if (params2[param_key2] != i[2]):
+                            if (last_matched != i[1]):
+                                output_file.write(param_key2)
+                                output_file.write(': ')
+                                output_file.write(str(params2[param_key2]))
+                                output_file.write(' -> ')
+                                output_file.write(str(i[2]))
+                                output_file.write('\n')
+                            else:
+                                output_file.write(last_matched)
+                                output_file.write(': ')
+                                output_file.write(str(last_matched_val,5))
+                                output_file.write(' -> ')
+                                output_file.write(str(i[2],5))
+                                output_file.write('\n')
\ No newline at end of file
